@@ -76,10 +76,10 @@ define ([
         target.push('myProfileAction', {
             'name': 'myProfileAction',
             'type': 'daction',
-            'menuText': 'My profile',
+            'menuText': 'Profile',
             'aclProfile': 'passerby',
             'start': dactionStart('myProfileAction'),
-            'pushable': false
+            'pushable': true
         });
         target.push('empProfileEditSave', {
             'name': 'empProfileEditSave',
@@ -158,7 +158,7 @@ define ([
         target.push('actionPrivHistory', { // read-only
             'name': 'actionPrivHistory',
             'type': 'daction',
-            'menuText': 'Privilege (status) history',
+            'menuText': 'Status history',
             'aclProfile': 'passerby',
             'start': dactionStart('actionPrivHistory'),
             // this starts the privhistory dtable, and if the dataset changes
@@ -200,20 +200,12 @@ define ([
         });
 
         // Schedhistory actions
-        target.push('actionSchedHistory', { // read-only
+        target.push('actionSchedHistory', {
             'name': 'actionSchedHistory',
             'type': 'daction',
             'menuText': 'Schedule history',
-            'aclProfile': 'passerby',
+            'aclProfile': 'inactive',
             'start': dactionStart('actionSchedHistory'),
-            'pushable': true
-        });
-        target.push('actionSchedHistoryEdit', { // read-write
-            'name': 'actionSchedHistoryEdit',
-            'type': 'daction',
-            'menuText': 'Edit',
-            'aclProfile': 'admin',
-            'start': dactionStart('actionSchedHistoryEdit'),
             'pushable': false
         });
         target.push('schedHistorySaveAction', {
@@ -253,7 +245,7 @@ define ([
         target.push('actionSchedLookup', {
             'name': 'actionSchedLookup',
             'type': 'daction',
-            'menuText': 'Lookup',
+            'menuText': 'Detail',
             'aclProfile': 'inactive',
             'start': dactionStart('actionSchedLookup'),
             'pushable': false
@@ -303,7 +295,7 @@ define ([
         target.push('createSingleIntMenuItem', {
             'name': 'createSingleIntMenuItem',
             'type': 'daction',
-            'menuText': 'Single interval',
+            'menuText': 'Create single interval',
             'aclProfile': 'active',
             'start': dactionStart('createSingleIntMenuItem'),
             'pushable': false
