@@ -102,7 +102,7 @@ define ([
         target.push('createMultipleInt', {
             'name': 'createMultipleInt',
             'type': 'dform',
-            'menuText': 'Multiple intervals (\"Fillup\")',
+            'menuText': 'Create multiple intervals',
             'title': 'Create multiple intervals according to schedule',
             'preamble': "Hints: (1) TAB or ENTER to validate and advance to next field " +
                         "(2) enter month by name (e.g. \"June\") or number (e.g. \"6\"); " +
@@ -202,7 +202,7 @@ define ([
             'miniMenu': {
                 entries: ['selectActivityAction', 'createSingleIntSave']
             }
-        }); // createSingleInt
+        }); // createSingleIntFixedDay
 
         target.push('displaySingleInt', {
             'name': 'displaySingleInt',
@@ -219,8 +219,8 @@ define ([
         target.push('empProfile', {
             'name': 'empProfile',
             'type': 'dform',
-            'menuText': 'My profile',
-            'title': 'My profile',
+            'menuText': 'Profile',
+            'title': 'Employee profile',
             'preamble': null,
             'aclProfile': 'passerby',
             'entriesRead': [
@@ -234,7 +234,13 @@ define ([
                 entries.ePscode, entries.ePsid, entries.ePschedEffective
             ],
             'miniMenu': {
-                entries: ['empProfileEdit', 'ldapSync', 'empProfileSetSuperSearch']
+                entries: [
+                    'actionPrivHistory',
+                    'actionSchedHistory',
+                    'empProfileEdit',
+                    'ldapSync',
+                    'empProfileSetSuperSearch',
+                ]
             }
         }); // empProfile
 
