@@ -44,15 +44,6 @@ define ([
 
     return function () {
 
-        target.push('createInt', {
-            'name': 'createInt',
-            'type': 'dmenu',
-            'menuText': 'Create',
-            'title': 'Create interval(s)',
-            'aclProfile': 'active',
-            'entries': ['createSingleIntMenuItem', 'createMultipleInt',],
-        });
-
         target.push('mainAdmin', {
             'name': 'mainAdmin',
             'type': 'dmenu',
@@ -68,7 +59,7 @@ define ([
             'menuText': 'Employee',
             'title': 'Employee menu',
             'aclProfile': 'passerby',
-            'entries': ['myProfileAction', 'ldapLookup', 'searchEmployee']
+            'entries': ['myProfileAction', 'ldapLookup', 'searchEmployee',]
         });
 
         target.push('mainInt', {
@@ -77,7 +68,7 @@ define ([
             'menuText': 'Interval',
             'title': 'Interval menu',
             'aclProfile': 'passerby',
-            'entries': ['viewIntervalsPrep', 'createInt'],
+            'entries': ['viewIntervalsPrep', 'createSingleIntMenuItem', 'createMultipleInt',],
         });
 
         target.push('mainMenu', {
@@ -86,26 +77,17 @@ define ([
             'menuText': 'Main',
             'title': 'Main menu',
             'aclProfile': 'passerby',
-            'entries': ['mainEmpl', 'mainPriv', 'mainSched', 'mainInt', 'masqEmployee',
+            'entries': ['mainEmpl', 'mainInt', 'mainSched', 'masqEmployee',
                         'mainAdmin']
         });
 
-        target.push('mainPriv', {
-            'name': 'mainPriv',
-            'type': 'dmenu',
-            'menuText': 'Priv (status)',
-            'title': 'Priv (status) menu',
-            'aclProfile': 'passerby',
-            'entries': ['actionPrivHistory']
-        });
-
         target.push('mainSched', {
             'name': 'mainSched',
             'type': 'dmenu',
             'menuText': 'Schedule',
             'title': 'Schedule menu',
-            'aclProfile': 'passerby',
-            'entries': ['actionSchedHistory', 'schedLookup',
+            'aclProfile': 'admin',
+            'entries': ['schedLookup',
                         'browseAllSchedules', 'schedNew']
         });
 
