@@ -417,6 +417,7 @@ define ([
                 opts,
                 rest,
                 sc = function (st) {
+                    var ld;
                     if (st.code === 'DISPATCH_RECORDS_FOUND' ) {
                         opts = { "resultLine": st.count + " intervals found" };
                         // convert intvl to iNdate and iNtimerange
@@ -432,6 +433,7 @@ define ([
                             }
                             st.payload[i].iNtimerange = arr[1];
                         }
+                        opts['xtarget'] = 'viewIntervalsPrep'; // so we don't land in viewIntervalsAction
                         if (multipleDates) {
                             obj = {
                                 "beginDate": begin,
@@ -440,7 +442,10 @@ define ([
                             };
                             stack.push('multiDayViewer', obj, opts);
                         } else {
-                            opts['xtarget'] = 'viewIntervalsPrep';
+                            for (i = 0; i < st.payload.length; i += 1) {
+                                ld = (st.payload[i].long_desc === undefined) ? "" : st.payload[i].long_desc;
+                                st.payload[i].long_desc = ld.slice(0, 30);
+                            }
                             stack.push('viewIntervalsDrowselect', {
                                 'pos': 0,
                                 'set': st.payload
@@ -451,13 +456,16 @@ define ([
                     } else {
                         coreLib.displayError(st.code + ": " + st.text);
                     }
+                },
+                fc = function (st) {
+                    stack.pop(undefined, {"resultLine": st.payload.message});
                 };
             [begin, end] = viewIntervalsActionCache();
             rest = {
                 "method": 'GET',
                 "path": 'interval/eid/' + cu.eid + "/[" + String(begin) + " 00:00, " + String(end) + " 24:00 )",
             };
-            ajax(rest, sc);
+            ajax(rest, sc, fc);
         },
         viewIntervalsCache = [],
 
