@@ -104,7 +104,7 @@ define ([
                     "Employee profile cache populated with employee \"demo\""
                 );
                 ct.mainMenuToMainEmpl(assert);
-                assert.ok(true, 'select 0 ("My profile") in mainEmpl as demo');
+                assert.ok(true, 'select 0 ("Profile") in mainEmpl as demo');
                 $('input[name="sel"]').val('0');
                 $('input[name="sel"]').focus();
                 $('input[name="sel"]').trigger($.Event("keydown", {keyCode: 13}));
